Module auth

Module auth 

Functions

get_api_client
Get API client for current account
get_api_client_for_server
Get API client for a specific server (without authentication)
get_current_account
Get the current account from config
remove_account
Remove an account from config
require_admin
Check if the current account has admin role
require_developer
Check if the current account has developer role (or higher)
require_role
Check if the current account has a specific role
save_account
Save account credentials to config
save_account_with_role
Save account credentials with role to config
switch_account
Switch to a different account
verify_current_account
Verify current account token is valid