Functions
- get_
api_ client - Get API client for current account
- get_
api_ client_ for_ server - Get API client for a specific server (without authentication)
- get_
current_ account - Get the current account from config
- remove_
account - Remove an account from config
- require_
admin - Check if the current account has admin role
- require_
developer - Check if the current account has developer role (or higher)
- require_
role - Check if the current account has a specific role
- save_
account - Save account credentials to config
- save_
account_ with_ role - Save account credentials with role to config
- switch_
account - Switch to a different account
- verify_
current_ account - Verify current account token is valid